@@ -11,7 +11,7 @@ from ..utils import (
 class ImdbIE(InfoExtractor):
     IE_NAME = u'imdb'
     IE_DESC = u'Internet Movie Database trailers'
-    _VALID_URL = r'http://www\.imdb\.com/video/imdb/vi(?P<id>\d+)'
+    _VALID_URL = r'http://(?:www|m)\.imdb\.com/video/imdb/vi(?P<id>\d+)'
 
     _TEST = {
         u'url': u'http://www.imdb.com/video/imdb/vi2524815897',
@@ -21,20 +21,20 @@ class ImdbIE(InfoExtractor):
             u'ext': u'mp4',
             u'title': u'Ice Age: Continental Drift Trailer (No. 2) - IMDb',
             u'description': u'md5:9061c2219254e5d14e03c25c98e96a81',
-            u'duration': 151,
         }
     }
 
     def _real_extract(self, url):
         mobj = re.match(self._VALID_URL, url)
         video_id = mobj.group('id')
-        webpage = self._download_webpage(url,video_id)
+        webpage = self._download_webpage('http://www.imdb.com/video/imdb/vi%s' % video_id, video_id)
         descr = get_element_by_attribute('itemprop', 'description', webpage)
         available_formats = re.findall(
             r'case \'(?P<f_id>.*?)\' :$\s+url = \'(?P<path>.*?)\'', webpage,
             flags=re.MULTILINE)
         formats = []
         for f_id, f_path in available_formats:
+            f_path = f_path.strip()
             format_page = self._download_webpage(
                 compat_urlparse.urljoin(url, f_path),
                 u'Downloading info for %s format' % f_id)
@@ -46,7 +46,6 @@ class ImdbIE(InfoExtractor):
             formats.append({
                 'format_id': f_id,
                 'url': format_info['url'],
-                'height': int(info['titleObject']['encoding']['selected'][:-1]),
             })
 
         return {
@@ -55,5 +54,4 @@ class ImdbIE(InfoExtractor):
             'formats': formats,
             'description': descr,
             'thumbnail': format_info['slate'],
-            'duration': int(info['titleObject']['title']['duration_seconds']),
         }
